@@ -61,10 +61,10 @@ namespace Kwave
 	RecordPlugin(QObject *parent, const QVariantList &args);
 
 	/** Destructor */
-	virtual ~RecordPlugin();
+        virtual ~RecordPlugin() Q_DECL_OVERRIDE;
 
 	/** @see Kwave::Plugin::setup() */
-	QStringList *setup(QStringList &previous_params) Q_DECL_OVERRIDE;
+        virtual QStringList *setup(QStringList &previous_params) Q_DECL_OVERRIDE;
 
     signals:
 
